<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2020 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2019.3/2027974
 */

use Application\Model\IModelDAO;
use Redis\Model\GroupDAO;
use Groups\Controller\IndexController;
use Application\View\Helper\ViewHelperFactory;
use Application\Controller\IndexControllerFactory;
use Application\Factory\InvokableServiceFactory;
use Groups\Filter\Group as GroupFilter;
use Application\Config\Services;

return [
    'groups' => [
        'edit_name_admin_only' => false,    // if enabled only admin users can edit group name
        'super_only'           => false,    // if enabled only super users can view groups pages
    ],
    'router' => [
        'routes' => [
            'group' => [
                'type' => 'Application\Router\Regex',
                'options' => [
                    'regex'    => '/group(s?)/(?P<group>.*[^/])(/?)',
                    'spec'     => '/groups/%group%',
                    'defaults' => [
                        'controller' => IndexController::class,
                        'action'     => 'group'
                    ],
                ],
            ],
            'add-group' => [
                'type' => 'Zend\Router\Http\Segment',
                'options' => [
                    'route'    => '/group[s]/add[/]',
                    'defaults' => [
                        'controller' => IndexController::class,
                        'action'     => 'add',
                    ],
                ],
            ],
            'edit-group' => [
                'type' => 'Application\Router\Regex',
                'options' => [
                    'regex'    => '/group(s?)/(?P<group>.*[^/])(/?)/settings(/?)',
                    'spec'     => '/groups/%group%/settings/',
                    'defaults' => [
                        'controller' => IndexController::class,
                        'action'     => 'edit'
                    ],
                ],
            ],
            'edit-notifications' => [
                'type' => 'Application\Router\Regex',
                'options' => [
                    'regex'    => '/group(s?)/(?P<group>.*[^/])(/?)/notifications(/?)',
                    'spec'     => '/groups/%group%/notifications/',
                    'defaults' => [
                        'controller' => IndexController::class,
                        'action'     => 'notifications'
                    ],
                ],
            ],
            'delete-group' => [
                'type' => 'Application\Router\Regex',
                'options' => [
                    'regex'    => '/group(s?)/delete/(?P<group>.*[^/])(/?)',
                    'spec'     => '/groups/delete/%group%',
                    'defaults' => [
                        'controller' => IndexController::class,
                        'action'     => 'delete'
                    ],
                ],
            ],
            'group-reviews' => [
                'type' => 'Application\Router\Regex',
                'options' => [
                    'regex'    => '/group(s?)/(?P<group>.*[^/])(/?)/reviews(/?)',
                    'spec'     => '/groups/%group%/reviews/',
                    'defaults' => [
                        'controller' => IndexController::class,
                        'action'     => 'reviews'
                    ],
                ],
            ],
            'groups' => [
                'type' => 'Zend\Router\Http\Segment',
                'options' => [
                    'route'    => '/groups[/]',
                    'defaults' => [
                        'controller' => IndexController::class,
                        'action'     => 'groups'
                    ],
                ],
            ],
        ],
    ],
    'controllers' => [
        'factories' => [
            IndexController::class => IndexControllerFactory::class
        ],
    ],
    'service_manager' => [
        'aliases' => [
            IModelDAO::GROUP_DAO   => GroupDAO::class,
            Services::GROUP_FILTER => GroupFilter::class
        ],
        'factories' => [
            GroupDAO::class    => InvokableServiceFactory::class,
            GroupFilter::class => InvokableServiceFactory::class,
        ],
    ],
    'view_manager' => [
        'template_path_stack'   => [
            __DIR__ . '/../view',
        ],
    ],
    'view_helpers' => [
        'factories' => array_fill_keys(
            [
                ViewHelperFactory::GROUP_TOOLBAR,
                ViewHelperFactory::GROUP_SIDEBAR,
                ViewHelperFactory::GROUP_AVATAR,
                ViewHelperFactory::GROUP_AVATARS,
                ViewHelperFactory::GROUP_NOT_SETTINGS
            ],
            ViewHelperFactory::class
        )
    ],
];
