<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2020 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2019.3/2027974
 */

use Api\Controller\IndexController;
use Api\IRequest;
use Application\Config\IConfigDefinition;
use Application\Config\IDao;
use Application\Controller\IndexControllerFactory;
use Application\Factory\InvokableServiceFactory;
use TestIntegration\Controller\TestRunApi;
use TestIntegration\Filter\ITestDefinition;
use TestIntegration\Filter\ITestRun;
use TestIntegration\Filter\TestDefinition as TestDefinitionFilter;
use TestIntegration\Filter\TestRun as TestRunFilter;
use TestIntegration\Model\TestDefinitionDAO;
use TestIntegration\Model\TestRunDAO;
use TestIntegration\Service\ITestExecutor;
use TestIntegration\Service\TestExecutor;

return [
    IConfigDefinition::GLOBAL_TESTS => [],
    'service_manager' => [
        'aliases' => [
            IDao::TEST_DEFINITION_DAO => TestDefinitionDAO::class,
            IDao::TEST_RUN_DAO        => TestRunDAO::class,
            ITestExecutor::NAME       => TestExecutor::class,
            ITestDefinition::NAME     => TestDefinitionFilter::class,
            ITestRun::NAME            => TestRunFilter::class
        ],
        'factories' => array_fill_keys(
            [
                TestDefinitionDAO::class,
                TestRunDAO::class,
                TestExecutor::class,
                TestDefinitionFilter::class,
                TestRunFilter::class
            ], InvokableServiceFactory::class
        ),
    ],
    'controllers' => [
        'factories' => [
            TestRunApi::class => IndexControllerFactory::class
        ]
    ],
    'router' => [
        'routes' => [
            'api' => [
                'type' => 'literal',
                'options' => [
                    'route' => IndexController::API_BASE,
                ],
                'may_terminate' => false,
                'child_routes' => [
                    'testruns' => [
                        'type' => 'Zend\Router\Http\Segment',
                        'options' => [
                            'route' => '/:version/reviews/:id/testruns[/]',
                            'constraints' => [IRequest::VERSION => 'v10'],
                        ],
                        'child_routes' => [
                            'action' => [
                                'type' => 'Zend\Router\Http\Method',
                                'options' => [
                                    'verb' => 'get, post',
                                    'defaults' => [
                                        'controller' => TestRunApi::class,
                                    ],
                                ],
                            ],
                        ],
                    ],
                    // POST for TestRuns to a specific test name
                    'testruns-test' => [
                        'type' => 'Zend\Router\Http\Segment',
                        'options' => [
                            'route' => '/:version/reviews/:id/testruns/:test[/]',
                            'constraints' => [IRequest::VERSION => 'v10'],
                        ],
                        'child_routes' => [
                            'action' => [
                                'type' => 'Zend\Router\Http\Method',
                                'options' => [
                                    'verb' => 'post',
                                    'defaults' => [
                                        'controller' => TestRunApi::class,
                                        'action'     => 'createForTest'
                                    ],
                                ],
                            ],
                        ],
                    ],
                    'testruns-update' => [
                        'type' => 'Zend\Router\Http\Segment',
                        'options' => [
                            'route' => '/:version/reviews/:reviewId/testruns/:id[/]',
                            'constraints' => [IRequest::VERSION => 'v10'],
                        ],
                        'child_routes' => [
                            'action' => [
                                'type' => 'Zend\Router\Http\Method',
                                'options' => [
                                    'verb' => 'put, patch',
                                    'defaults' => [
                                        'controller' => TestRunApi::class
                                    ],
                                ],
                            ],
                        ],
                    ],
                    // POST with uuid (no review)
                    'testruns-uuid' => [
                        'type' => 'Zend\Router\Http\Segment',
                        'options' => [
                            'route' => '/:version/testruns/:id/:uuid[/]',
                            'constraints' => [IRequest::VERSION => 'v10'],
                        ],
                        'child_routes' => [
                            'action' => [
                                'type' => 'Zend\Router\Http\Method',
                                'options' => [
                                    'verb' => 'post',
                                    'defaults' => [
                                        'controller' => TestRunApi::class,
                                        'action'     => 'updateWithUuid'
                                    ],
                                ],
                            ],
                        ],
                    ],
                    // GET with uuid (no review)
                    'testruns-pass' => [
                        'type' => 'Zend\Router\Http\Segment',
                        'options' => [
                            'route' => '/:version/testruns/:id/pass/:uuid[/]',
                            'constraints' => [IRequest::VERSION => 'v10'],
                        ],
                        'child_routes' => [
                            'action' => [
                                'type' => 'Zend\Router\Http\Method',
                                'options' => [
                                    'verb' => 'get, post',
                                    'defaults' => [
                                        'controller' => TestRunApi::class,
                                        'action'     => 'pass'
                                    ],
                                ],
                            ],
                        ],
                    ],
                    'testruns-fail' => [
                        'type' => 'Zend\Router\Http\Segment',
                        'options' => [
                            'route' => '/:version/testruns/:id/fail/:uuid[/]',
                            'constraints' => [IRequest::VERSION => 'v10'],
                        ],
                        'child_routes' => [
                            'action' => [
                                'type' => 'Zend\Router\Http\Method',
                                'options' => [
                                    'verb' => 'get, post',
                                    'defaults' => [
                                        'controller' => TestRunApi::class,
                                        'action'     => 'fail'
                                    ],
                                ],
                            ],
                        ],
                    ],
                ],
            ],
        ],
    ],
    // These are the UUID based endpoints that do not require authentication
    'security' => [
        'login_exempt'  => [TestRunApi::UPDATE_NOAUTH_URL_ROUTE, TestRunApi::PASS_URL_ROUTE, TestRunApi::FAIL_URL_ROUTE]
    ],
];
