<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2020 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2019.3/2027974
 */
namespace TestIntegration\Filter;

use Zend\Validator\AbstractValidator;

/**
 * Class StatusValidator to validate the test run status
 * @package TestIntegration\Filter
 */
class StatusValidator extends AbstractValidator
{
    // Statuses
    const STATUS_PASS    = 'pass';
    const STATUS_FAIL    = 'fail';
    const STATUS_RUNNING = 'running';
    const VALID_STATUSES = [self::STATUS_PASS, self::STATUS_FAIL, self::STATUS_RUNNING];
    const INVALID_STATUS = 'invalidStatus';

    private $translator;

    /**
     * StatusValidator constructor.
     * @param mixed     $translator     to translate messages
     */
    public function __construct($translator)
    {
        parent::__construct();
        $this->translator = $translator;
    }

    /**
     * Validate the status
     * @param mixed $value  value to validate
     * @return bool true if valid
     */
    public function isValid($value)
    {
        if (!in_array(strtolower($value), self::VALID_STATUSES)) {
            $this->abstractOptions['messages'][self::INVALID_STATUS] =
                $this->translator->t(
                    "Invalid status [%s], must be one of [%s]",
                    [$value, implode(', ', self::VALID_STATUSES)]
                );
            return false;
        }
        return true;
    }
}
