<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2020 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2019.3/2027974
 */
namespace TestIntegration\Model;

use Record\Key\AbstractKey;

/**
 * Class TestRun to define the model for review or change test runs
 * @package TestIntegration\Model
 */
class TestRun extends AbstractKey implements ITestRun
{
    // Perforce fields
    const KEY_PREFIX = 'swarm-testRun-';
    const KEY_COUNT  = 'swarm-testRun:count';

    // Model Fields
    const FIELD_ID             = 'id';
    const FIELD_CHANGE         = 'change';
    const FIELD_VERSION        = 'version';
    const FIELD_TEST           = 'test';
    const FIELD_START_TIME     = 'startTime';
    const FIELD_COMPLETED_TIME = 'completedTime';
    const FIELD_STATUS         = 'status';
    const FIELD_MESSAGES       = 'messages';
    const FIELD_URL            = 'url';
    const FIELD_UUID           = 'uuid';
    const FIELD_TITLE          = 'title';

    // Search fields
    const FETCH_BY_CHANGE = 'change';

    protected $fields = [
        self::FIELD_CHANGE => [
            self::INDEX    => 1801,
            self::ACCESSOR => 'getChange',
            self::MUTATOR  => 'setChange'
        ],
        self::FIELD_VERSION => [
            self::ACCESSOR => 'getVersion',
            self::MUTATOR  => 'setVersion'
        ],
        self::FIELD_TEST => [
            self::ACCESSOR => 'getTest',
            self::MUTATOR  => 'setTest'
        ],
        self::FIELD_START_TIME => [
            self::ACCESSOR => 'getStartTime',
            self::MUTATOR  => 'setStartTime'
        ],
        self::FIELD_COMPLETED_TIME => [
            self::ACCESSOR => 'getCompletedTime',
            self::MUTATOR  => 'setCompletedTime'
        ],
        self::FIELD_STATUS => [
            self::ACCESSOR => 'getStatus',
            self::MUTATOR  => 'setStatus'
        ],
        self::FIELD_MESSAGES => [
            self::ACCESSOR => 'getMessages',
            self::MUTATOR  => 'setMessages'
        ],
        self::FIELD_URL => [
            self::ACCESSOR => 'getUrl',
            self::MUTATOR  => 'setUrl'
        ],
        self::FIELD_UUID => [
            self::ACCESSOR => 'getUuid',
            self::MUTATOR  => 'setUuid'
        ],
        self::FIELD_TITLE => [
            self::ACCESSOR => 'getTitle',
            self::MUTATOR  => 'setTitle'
        ],
    ];

    /**
     * @inheritDoc
     */
    public function getChange(): int
    {
        return $this->getRawValue(self::FIELD_CHANGE);
    }

    /**
     * @inheritDoc
     */
    public function setChange(int $change)
    {
        return $this->setRawValue(self::FIELD_CHANGE, $change);
    }

    /**
     * @inheritDoc
     */
    public function getVersion()
    {
        return $this->getRawValue(self::FIELD_VERSION);
    }

    /**
     * @inheritDoc
     */
    public function setVersion(int $version)
    {
        return $this->setRawValue(self::FIELD_VERSION, $version);
    }

    /**
     * @inheritDoc
     */
    public function getTest(): string
    {
        return $this->getRawValue(self::FIELD_TEST);
    }

    /**
     * @inheritDoc
     */
    public function setTest(string $test)
    {
        return $this->setRawValue(self::FIELD_TEST, $test);
    }

    /**
     * @inheritDoc
     */
    public function getStatus()
    {
        return $this->getRawValue(self::FIELD_STATUS);
    }

    /**
     * @inheritDoc
     */
    public function setStatus(string $status)
    {
        return $this->setRawValue(self::FIELD_STATUS, $status);
    }

    /**
     * @inheritDoc
     */
    public function getUrl()
    {
        return $this->getRawValue(self::FIELD_URL);
    }

    /**
     * @inheritDoc
     */
    public function setUrl(string $url)
    {
        return $this->setRawValue(self::FIELD_URL, $url);
    }

    /**
     * @inheritDoc
     */
    public function getMessages()
    {
        return $this->getRawValue(self::FIELD_MESSAGES);
    }

    /**
     * @inheritDoc
     */
    public function setMessages(array $messages)
    {
        return $this->setRawValue(self::FIELD_MESSAGES, $messages);
    }

    /**
     * @inheritDoc
     */
    public function getStartTime(): int
    {
        return $this->getRawValue(self::FIELD_START_TIME);
    }

    /**
     * @inheritDoc
     */
    public function setStartTime(int $startTime)
    {
        return $this->setRawValue(self::FIELD_START_TIME, $startTime);
    }

    /**
     * @inheritDoc
     */
    public function getCompletedTime()
    {
        return $this->getRawValue(self::FIELD_COMPLETED_TIME);
    }

    /**
     * @inheritDoc
     */
    public function setCompletedTime($completedTime)
    {
        return $this->setRawValue(self::FIELD_COMPLETED_TIME, $completedTime);
    }

    /**
     * @inheritDoc
     */
    public function setUuid($uuid)
    {
        return $this->setRawValue(self::FIELD_UUID, $uuid);
    }

    /**
     * @inheritDoc
     */
    public function getUuid()
    {
        return $this->getRawValue(self::FIELD_UUID);
    }

    /**
     * @inheritDoc
     */
    public function getTitle()
    {
        return $this->getRawValue(self::FIELD_TITLE);
    }

    /**
     * @inheritDoc
     */
    public function setTitle($title)
    {
        return $this->setRawValue(self::FIELD_TITLE, $title);
    }
}
